==> nsafirstlibrary-1.0.0.tgz: package/nationalservicealliance.js <==
'use strict';

//Include global module
var globals = require('./global')

//Handles https
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";

//Declare method and path
var method, path

//Parameterized Constructor takes token parameter
function NationalServiceAlliance(token) {

    if (!(this instanceof NationalServiceAlliance)) {
        return new NationalServiceAlliance(token);
    }

    this.setToken(token);
}

//Calling API Resources
NationalServiceAlliance.prototype = {


    //Sets Token globally
    setToken: function (token) {

        globals.token = token

    },

    //Welcome method

    welcome: function (success) {
        method = globals.nsaBasicMethod.welcome.method
        path = globals.nsaBasicMethod.welcome.path

        globals.welcome.getWelcome(path, globals.host, success)
    },

    //Users Method
    listUsers: function (currentObject, success) {
        method = globals.nsaBasicMethod.listUsers.method
        path = globals.nsaBasicMethod.listUsers.path
        path = path + currentObject.state.id

        globals.users.getUsers(path, globals.host, currentObject, success)
    },

    updateUser: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateUser.method
        path = globals.nsaBasicMethod.updateUser.path
        path = path + currentObject.state.id

        globals.users.postUsers(path, globals.host, currentObject, success)
    },

    updateUserPassword: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateUserPassword.method
        path = globals.nsaBasicMethod.updateUserPassword.path
        path = path + currentObject.state.id + '/password'

        globals.users.putUserPassword(path, globals.host, currentObject, success)
    },


    //Authorizations Method
    login: function (currentObject, success) {
        method = globals.nsaBasicMethod.login.method
        path = globals.nsaBasicMethod.login.path

        globals.authorizations.postAuthorizations(path, globals.host, currentObject, success)

    },

    refreshLogin: function (currentObject, success) {
        method = globals.nsaBasicMethod.refreshLogin.method
        path = globals.nsaBasicMethod.refreshLogin.path

        globals.authorizations.postRefreshAuthorizations(path, globals.host, currentObject, success)
    },

    logout: function (currentObject, success) {
        method = globals.nsaBasicMethod.logout.method
        path = globals.nsaBasicMethod.logout.path

        globals.authorizations.logout(path, globals.host, currentObject, success)
    },

    //Availability Methods
    listAvailability: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailability.method
        path = globals.nsaBasicMethod.listAvailability.path

        globals.availability.getAvailability(path, globals.host, currentObject, success)
    },

    listAvailabilityWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailabilityWithHash.method
        path = globals.nsaBasicMethod.listAvailabilityWithHash.path

        globals.availability.getAvailabilityWithHash(path, globals.host, currentObject, success)
    },

    listAvailabilityDefaults: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailabilityDefaults.method
        path = globals.nsaBasicMethod.listAvailabilityDefaults.path

        globals.availability.getAvailabilityDefaults(path, globals.host, currentObject, success)
    },

    addAvailability: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailability.method
        path = globals.nsaBasicMethod.updateAvailability.path

        globals.availability.postAvailability(path, globals.host, currentObject, success)
    },

    updateAvailabilityByDate: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailabilityByDate.method
        path = globals.nsaBasicMethod.updateAvailabilityByDate.path
        path = path + currentObject.state.date

        globals.availability.putAvailabilityByDate(path, globals.host, currentObject, success)
    },

    removeAvailabilityByDate: function (currentObject, success) {
        method = globals.nsaBasicMethod.removeAvailabilityByDate.method
        path = globals.nsaBasicMethod.removeAvailabilityByDate.path
        path = path + currentObject.state.date

        globals.availability.deleteAvailabilityByDate(path, globals.host, currentObject, success)
    },

    updateAvailabilityDefaults: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailabilityDefaults.method
        path = globals.nsaBasicMethod.updateAvailabilityDefaults.path

        globals.availability.postAvailabilityDefaults(path, globals.host, currentObject, success)
    },

    //Dispatches Methods
    getDispatches: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatches.method
        path = globals.nsaBasicMethod.listDispatches.path
        path = path + currentObject.state.queryString
        
        globals.dispatches.getDispatches(path, globals.host, currentObject, success)
    },

    //getDispatchesWithHash geting list of dispatches with hash on POST request
    getDispatchesWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesWithHash.method
        path = globals.nsaBasicMethod.listDispatchesWithHash.path
        path = path + currentObject.state.queryString

        globals.dispatches.getDispatchesWithHash(path, globals.host, currentObject, success)
    },

    getDispatchesByDispatchNumber: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesByDispatchNumber.method
        path = globals.nsaBasicMethod.listDispatchesByDispatchNumber.path
        path = path + currentObject.state.dispatchNumber

        globals.dispatches.getDispatchesByDispatchNumber(path, globals.host, currentObject, success)
    },

    updateDispatchesByDispatchNumber: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesByDispatchNumber.method
        path = globals.nsaBasicMethod.updateDispatchesByDispatchNumber.path
        path = path + currentObject.state.dispatchNumber

        globals.dispatches.updateDispatchesByDispatchNumber(path, globals.host, currentObject, success)
    },

    updateDispatchesSchedules: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesSchedules.method
        path = globals.nsaBasicMethod.updateDispatchesSchedules.path
        path = path + currentObject.state.dispatchNumber + '/schedules'

        globals.dispatches.updateDispatchesSchedules(path, globals.host, currentObject, success)
    },

    updateDispatchesCompletions: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesCompletions.method
        path = globals.nsaBasicMethod.updateDispatchesCompletions.path
        path = path + currentObject.state.dispatchNumber + '/completions/close'

        globals.dispatches.updateDispatchesCompletions(path, globals.host, currentObject, success)
    },

    getDispatchesAttachments: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesAttachments.method
        path = globals.nsaBasicMethod.listDispatchesAttachments.path
        path = path + currentObject.state.dispatchNumber + '/attachments'

        globals.dispatches.getDispatchesAttachments(path, globals.host, currentObject, success)
    },

    addDispatchesAttachments: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesAttachments.method
        path = globals.nsaBasicMethod.updateDispatchesAttachments.path
        path = path + currentObject.state.dispatchNumber + '/attachments'

        globals.dispatches.addDispatchesAttachments(path, globals.host, currentObject, success)
    },

    //Payment Methods 
    listPayments: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPayments.method
        path = globals.nsaBasicMethod.listPayments.path
        path = path + currentObject.state.queryString

        globals.payments.getPayments(path, globals.host, currentObject, success)
    },

    listPaymentsWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsWithHash.method
        path = globals.nsaBasicMethod.listPaymentsWithHash.path
        path = path + currentObject.state.queryString

        globals.payments.getPaymentsWithHash(path, globals.host, currentObject, success)
    },

    listPaymentsByBatchId: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsByBatchId.method
        path = globals.nsaBasicMethod.listPaymentsByBatchId.path
        path = path + currentObject.state.batchID

        globals.payments.getPaymentsBatches(path, globals.host, currentObject, success)
    },

    listPaymentsByCallId: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsByCallId.method
        path = globals.nsaBasicMethod.listPaymentsByCallId.path
        path = path + currentObject.state.callID

        globals.payments.getPaymentsCalls(path, globals.host, currentObject, success)
    }

}

module.exports = NationalServiceAlliance;

// expose constructor as a named property 
module.exports.NationalServiceAlliance = NationalServiceAlliance;

==> nsafirstlibrary-2.0.0.tgz: package/nationalservicealliance.js <==
'use strict';

//Include global module
var globals = require('./global')

//Handles https
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";

//Declare method and path
var method, path

//Parameterized Constructor takes token parameter
function NationalServiceAlliance(token) {

    if (!(this instanceof NationalServiceAlliance)) {
        return new NationalServiceAlliance(token);
    }

    this.setToken(token);
}

//Calling API Resources
NationalServiceAlliance.prototype = {

    //Sets Token globally
    setToken: function (token) {

        globals.token = token

    },

    //Welcome method

    welcome: function (success) {
        method = globals.nsaBasicMethod.welcome.method
        path = globals.nsaBasicMethod.welcome.path

        globals.welcome.getWelcome(path, globals.host, success)
    },

    //Users Method
    listUsers: function (currentObject, success) {
        method = globals.nsaBasicMethod.listUsers.method
        path = globals.nsaBasicMethod.listUsers.path
        path = path + currentObject.state.id

        globals.users.getUsers(path, globals.host, globals.token, currentObject, success)
    },

    updateUser: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateUser.method
        path = globals.nsaBasicMethod.updateUser.path
        path = path + currentObject.state.id

        globals.users.postUsers(path, globals.host, globals.token, currentObject, success)
    },

    updateUserPassword: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateUserPassword.method
        path = globals.nsaBasicMethod.updateUserPassword.path
        path = path + currentObject.state.id + '/password'

        globals.users.putUserPassword(path, globals.host, globals.token, currentObject, success)
    },


    //Authorizations Method
    login: function (currentObject, success) {
        method = globals.nsaBasicMethod.login.method
        path = globals.nsaBasicMethod.login.path

        globals.authorizations.postAuthorizations(path, globals.host, currentObject, success)

    },

    refreshLogin: function (currentObject, success) {
        method = globals.nsaBasicMethod.refreshLogin.method
        path = globals.nsaBasicMethod.refreshLogin.path

        globals.authorizations.postRefreshAuthorizations(path, globals.host, globals.token, currentObject, success)
    },

    logout: function (currentObject, success) {
        method = globals.nsaBasicMethod.logout.method
        path = globals.nsaBasicMethod.logout.path

        globals.authorizations.logout(path, globals.host, globals.token, currentObject, success)
    },

    //Availability Methods
    listAvailability: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailability.method
        path = globals.nsaBasicMethod.listAvailability.path

        globals.availability.getAvailability(path, globals.host, globals.token, currentObject, success)
    },

    listAvailabilityWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailabilityWithHash.method
        path = globals.nsaBasicMethod.listAvailabilityWithHash.path

        globals.availability.getAvailabilityWithHash(path, globals.host, globals.token, currentObject, success)
    },

    listAvailabilityDefaults: function (currentObject, success) {
        method = globals.nsaBasicMethod.listAvailabilityDefaults.method
        path = globals.nsaBasicMethod.listAvailabilityDefaults.path

        globals.availability.getAvailabilityDefaults(path, globals.host, globals.token, currentObject, success)
    },

    addAvailability: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailability.method
        path = globals.nsaBasicMethod.updateAvailability.path

        globals.availability.postAvailability(path, globals.host, globals.token, currentObject, success)
    },

    updateAvailabilityByDate: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailabilityByDate.method
        path = globals.nsaBasicMethod.updateAvailabilityByDate.path
        path = path + currentObject.state.date

        globals.availability.putAvailabilityByDate(path, globals.host, globals.token, currentObject, success)
    },

    removeAvailabilityByDate: function (currentObject, success) {
        method = globals.nsaBasicMethod.removeAvailabilityByDate.method
        path = globals.nsaBasicMethod.removeAvailabilityByDate.path
        path = path + currentObject.state.date

        globals.availability.deleteAvailabilityByDate(path, globals.host, globals.token, currentObject, success)
    },

    updateAvailabilityDefaults: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateAvailabilityDefaults.method
        path = globals.nsaBasicMethod.updateAvailabilityDefaults.path

        globals.availability.postAvailabilityDefaults(path, globals.host, globals.token, currentObject, success)
    },

    //Dispatches Methods
    getDispatches: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatches.method
        path = globals.nsaBasicMethod.listDispatches.path
        path = path + currentObject.state.queryString

        globals.dispatches.getDispatches(path, globals.host, globals.token, currentObject, success)
    },

    //getDispatchesWithHash geting list of dispatches with hash on POST request
    getDispatchesWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesWithHash.method
        path = globals.nsaBasicMethod.listDispatchesWithHash.path
        path = path + currentObject.state.queryString

        globals.dispatches.getDispatchesWithHash(path, globals.host, globals.token, currentObject, success)
    },

    getDispatchesByDispatchNumber: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesByDispatchNumber.method
        path = globals.nsaBasicMethod.listDispatchesByDispatchNumber.path
        path = path + currentObject.state.dispatchNumber

        globals.dispatches.getDispatchesByDispatchNumber(path, globals.host, globals.token, currentObject, success)
    },

    updateDispatchesByDispatchNumber: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesByDispatchNumber.method
        path = globals.nsaBasicMethod.updateDispatchesByDispatchNumber.path
        path = path + currentObject.state.dispatchNumber

        globals.dispatches.updateDispatchesByDispatchNumber(path, globals.host, globals.token, currentObject, success)
    },

    updateDispatchesSchedules: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesSchedules.method
        path = globals.nsaBasicMethod.updateDispatchesSchedules.path
        path = path + currentObject.state.dispatchNumber + '/schedules'

        globals.dispatches.updateDispatchesSchedules(path, globals.host, globals.token, currentObject, success)
    },

    updateDispatchesCompletions: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesCompletions.method
        path = globals.nsaBasicMethod.updateDispatchesCompletions.path
        path = path + currentObject.state.dispatchNumber + '/completions/close'

        globals.dispatches.updateDispatchesCompletions(path, globals.host, globals.token, currentObject, success)
    },

    getDispatchesAttachments: function (currentObject, success) {
        method = globals.nsaBasicMethod.listDispatchesAttachments.method
        path = globals.nsaBasicMethod.listDispatchesAttachments.path
        path = path + currentObject.state.dispatchNumber + '/attachments'

        globals.dispatches.getDispatchesAttachments(path, globals.host, globals.token, currentObject, success)
    },

    addDispatchesAttachments: function (currentObject, success) {
        method = globals.nsaBasicMethod.updateDispatchesAttachments.method
        path = globals.nsaBasicMethod.updateDispatchesAttachments.path
        path = path + currentObject.state.dispatchNumber + '/attachments'

        globals.dispatches.addDispatchesAttachments(path, globals.host, globals.token, currentObject, success)
    },

    //Payment Methods 
    listPayments: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPayments.method
        path = globals.nsaBasicMethod.listPayments.path
        path = path + currentObject.state.queryString

        globals.payments.getPayments(path, globals.host, globals.token, currentObject, success)
    },

    listPaymentsWithHash: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsWithHash.method
        path = globals.nsaBasicMethod.listPaymentsWithHash.path
        path = path + currentObject.state.queryString

        globals.payments.getPaymentsWithHash(path, globals.host, globals.token, currentObject, success)
    },

    listPaymentsByBatchId: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsByBatchId.method
        path = globals.nsaBasicMethod.listPaymentsByBatchId.path
        path = path + currentObject.state.batchID

        globals.payments.getPaymentsBatches(path, globals.host, globals.token, currentObject, success)
    },

    listPaymentsByCallId: function (currentObject, success) {
        method = globals.nsaBasicMethod.listPaymentsByCallId.method
        path = globals.nsaBasicMethod.listPaymentsByCallId.path
        path = path + currentObject.state.callID

        globals.payments.getPaymentsCalls(path, globals.host, globals.token, currentObject, success)
    }

}

module.exports = NationalServiceAlliance;

// expose constructor as a named property 
module.exports.NationalServiceAlliance = NationalServiceAlliance;
